import { LoadingService } from '@zeedhi/common';
import { I18n } from '@zeedhi/core';
import TekLibAuthApi from './TekLibAuthApi';
import TekLibAuthService from './TekLibAuthService';
import { Util } from '../Utilities/Util';
import { TekLibLocalStorage } from '../Helpers/TekLibLocalStorage';

export class TekLibAuth {
  private static tekLibAuthService: TekLibAuthService = TekLibAuthService.getInstance();

  public static async startSession(userData: any) {
    LoadingService.show();
    await this.tekLibAuthService.startSession(userData);
    LoadingService.hide();
  }

  public static showMessageExpiredMenu() {
    this.tekLibAuthService.showMessageExpiredMenu();
  }

  public static async logout() {
    await this.tekLibAuthService.logout();
  }

  public static async logoutConfirm() {
    await this.tekLibAuthService.logoutConfirm();
  }

  public static async updateSession(user: object, accessProfile: object[], otherSessionValues: object) {
    return new Promise((resolve, reject) => {
      TekLibAuthApi.updateSession(user, accessProfile, otherSessionValues)
        .then((response) => {
          if (!response.data.user) {
            reject(response);
          }
          localStorage.setItem('LOGIN_USER', response.data.user);
          resolve(true);
        })
        .catch((error) => {
          reject(error);
        });
    });
  }

  public static saveCollectedData(collectionIds: any, operationId: any, productId = null,
    operatorCode = null, operatorName = null, organizationId = null): Promise<any> {
    return TekLibAuthApi.saveCollectedData(collectionIds, operationId, productId, operatorCode, operatorName, organizationId);
  }

  public static async startLib() {
    window.addEventListener('message', this.handleMessageEvent);
    if (!TekLibLocalStorage.getItem('IS_NEXT')) {
      this.tekLibAuthService.sendVersionInfoForZeedhiAngular();
    }
    await this.tekLibAuthService.checkExpiredSession();
    if (Util.isProduct()) {
      TekLibAuthService.getInstance().setInitLocalStorage();
    }
    const language = localStorage.getItem('LOGIN_LANGUAGE');
    if (language) {
      const languageParts = language.split('_');
      const lang = `${languageParts[0]}-${languageParts[1].toUpperCase()}`;
      I18n.changeLanguage(lang);
    }
  }

  private static async handleMessageEvent(event: any) {
    if (event.data.type === 'createSessionTime') {
      TekLibAuthService.getInstance().factoryExpiredSessionMethod();
    } else if (event.data.type === 'updateTranslation') {
      let isError = false;
      let message = '';
      try {
        await TekLibAuthApi.updateTranslation();
      } catch (error) {
        isError = true;
        message = error.response.data.error ? error.response.data.error : error.response.data;
      }
      window.parent.postMessage({
        type: 'updateTranslationNext',
        data: {
          isError,
          message,
        },
      }, window.location.ancestorOrigins[0]);
    }
  }
}
